@@ -6,7 +6,7 @@ use MooseX::Singleton::Role::Object;
 use MooseX::Singleton::Role::Meta::Class;
 use MooseX::Singleton::Role::Meta::Instance;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 $VERSION = eval $VERSION;
 
 Moose::Exporter->setup_import_methods( also => 'Moose' );
@@ -19,13 +19,15 @@ sub init_meta {
 
     my $caller = $p{for_class};
 
-    Moose::Util::MetaRole::apply_metaclass_roles(
-        for_class       => $caller,
-        metaclass_roles => ['MooseX::Singleton::Role::Meta::Class'],
-        instance_metaclass_roles =>
-            ['MooseX::Singleton::Role::Meta::Instance'],
-        constructor_class_roles =>
-            ['MooseX::Singleton::Role::Meta::Method::Constructor'],
+    Moose::Util::MetaRole::apply_metaroles(
+        for             => $caller,
+        class_metaroles => {
+            class => ['MooseX::Singleton::Role::Meta::Class'],
+            instance =>
+                ['MooseX::Singleton::Role::Meta::Instance'],
+            constructor =>
+                ['MooseX::Singleton::Role::Meta::Method::Constructor'],
+        },
     );
 
     Moose::Util::MetaRole::apply_base_class_roles(
